(function () {
'use strict';

var pug = (function(exports){
  'use strict';

  var pug_has_own_property = Object.prototype.hasOwnProperty;

  /**
   * Merge two attribute objects giving precedence
   * to values in object `b`. Classes are special-cased
   * allowing for arrays and merging/joining appropriately
   * resulting in a string.
   *
   * @param {Object} a
   * @param {Object} b
   * @return {Object} a
   * @api private
   */

  exports.merge = pug_merge;
  function pug_merge(a, b) {
    if (arguments.length === 1) {
      var attrs = a[0];
      for (var i = 1; i < a.length; i++) {
        attrs = pug_merge(attrs, a[i]);
      }
      return attrs;
    }

    for (var key in b) {
      if (key === 'class') {
        var valA = a[key] || [];
        a[key] = (Array.isArray(valA) ? valA : [valA]).concat(b[key] || []);
      } else if (key === 'style') {
        var valA = pug_style(a[key]);
        var valB = pug_style(b[key]);
        a[key] = valA + valB;
      } else {
        a[key] = b[key];
      }
    }

    return a;
  };

  /**
   * Process array, object, or string as a string of classes delimited by a space.
   *
   * If `val` is an array, all members of it and its subarrays are counted as
   * classes. If `escaping` is an array, then whether or not the item in `val` is
   * escaped depends on the corresponding item in `escaping`. If `escaping` is
   * not an array, no escaping is done.
   *
   * If `val` is an object, all the keys whose value is truthy are counted as
   * classes. No escaping is done.
   *
   * If `val` is a string, it is counted as a class. No escaping is done.
   *
   * @param {(Array.<string>|Object.<string, boolean>|string)} val
   * @param {?Array.<string>} escaping
   * @return {String}
   */
  exports.classes = pug_classes;
  function pug_classes_array(val, escaping) {
    var classString = '', className, padding = '', escapeEnabled = Array.isArray(escaping);
    for (var i = 0; i < val.length; i++) {
      className = pug_classes(val[i]);
      if (!className) continue;
      escapeEnabled && escaping[i] && (className = pug_escape(className));
      classString = classString + padding + className;
      padding = ' ';
    }
    return classString;
  }
  function pug_classes_object(val) {
    var classString = '', padding = '';
    for (var key in val) {
      if (key && val[key] && pug_has_own_property.call(val, key)) {
        classString = classString + padding + key;
        padding = ' ';
      }
    }
    return classString;
  }
  function pug_classes(val, escaping) {
    if (Array.isArray(val)) {
      return pug_classes_array(val, escaping);
    } else if (val && typeof val === 'object') {
      return pug_classes_object(val);
    } else {
      return val || '';
    }
  }

  /**
   * Convert object or string to a string of CSS styles delimited by a semicolon.
   *
   * @param {(Object.<string, string>|string)} val
   * @return {String}
   */

  exports.style = pug_style;
  function pug_style(val) {
    if (!val) return '';
    if (typeof val === 'object') {
      var out = '';
      for (var style in val) {
        /* istanbul ignore else */
        if (pug_has_own_property.call(val, style)) {
          out = out + style + ':' + val[style] + ';';
        }
      }
      return out;
    } else {
      val += '';
      if (val[val.length - 1] !== ';') 
        return val + ';';
      return val;
    }
  };

  /**
   * Render the given attribute.
   *
   * @param {String} key
   * @param {String} val
   * @param {Boolean} escaped
   * @param {Boolean} terse
   * @return {String}
   */
  exports.attr = pug_attr;
  function pug_attr(key, val, escaped, terse) {
    if (val === false || val == null || !val && (key === 'class' || key === 'style')) {
      return '';
    }
    if (val === true) {
      return ' ' + (terse ? key : key + '="' + key + '"');
    }
    if (typeof val.toJSON === 'function') {
      val = val.toJSON();
    }
    if (typeof val !== 'string') {
      val = JSON.stringify(val);
      if (!escaped && val.indexOf('"') !== -1) {
        return ' ' + key + '=\'' + val.replace(/'/g, '&#39;') + '\'';
      }
    }
    if (escaped) val = pug_escape(val);
    return ' ' + key + '="' + val + '"';
  };

  /**
   * Render the given attributes object.
   *
   * @param {Object} obj
   * @param {Object} terse whether to use HTML5 terse boolean attributes
   * @return {String}
   */
  exports.attrs = pug_attrs;
  function pug_attrs(obj, terse){
    var attrs = '';

    for (var key in obj) {
      if (pug_has_own_property.call(obj, key)) {
        var val = obj[key];

        if ('class' === key) {
          val = pug_classes(val);
          attrs = pug_attr(key, val, false, terse) + attrs;
          continue;
        }
        if ('style' === key) {
          val = pug_style(val);
        }
        attrs += pug_attr(key, val, false, terse);
      }
    }

    return attrs;
  };

  /**
   * Escape the given string of `html`.
   *
   * @param {String} html
   * @return {String}
   * @api private
   */

  var pug_match_html = /["&<>]/;
  exports.escape = pug_escape;
  function pug_escape(_html){
    var html = '' + _html;
    var regexResult = pug_match_html.exec(html);
    if (!regexResult) return _html;

    var result = '';
    var i, lastIndex, escape;
    for (i = regexResult.index, lastIndex = 0; i < html.length; i++) {
      switch (html.charCodeAt(i)) {
        case 34: escape = '&quot;'; break;
        case 38: escape = '&amp;'; break;
        case 60: escape = '&lt;'; break;
        case 62: escape = '&gt;'; break;
        default: continue;
      }
      if (lastIndex !== i) result += html.substring(lastIndex, i);
      lastIndex = i + 1;
      result += escape;
    }
    if (lastIndex !== i) return result + html.substring(lastIndex, i);
    else return result;
  };

  /**
   * Re-throw the given `err` in context to the
   * the pug in `filename` at the given `lineno`.
   *
   * @param {Error} err
   * @param {String} filename
   * @param {String} lineno
   * @param {String} str original source
   * @api private
   */

  exports.rethrow = pug_rethrow;
  function pug_rethrow(err, filename, lineno, str){
    if (!(err instanceof Error)) throw err;
    if ((typeof window != 'undefined' || !filename) && !str) {
      err.message += ' on line ' + lineno;
      throw err;
    }
    try {
      str = str || require('fs').readFileSync(filename, 'utf8')
    } catch (ex) {
      pug_rethrow(err, null, lineno)
    }
    var context = 3
      , lines = str.split('\n')
      , start = Math.max(lineno - context, 0)
      , end = Math.min(lines.length, lineno + context);

    // Error context
    var context = lines.slice(start, end).map(function(line, i){
      var curr = i + start + 1;
      return (curr == lineno ? '  > ' : '    ')
        + curr
        + '| '
        + line;
    }).join('\n');

    // Alter exception message
    err.path = filename;
    err.message = (filename || 'Pug') + ':' + lineno
      + '\n' + context + '\n\n' + err.message;
    throw err;
  };

  return exports
})({});

function templateTwitter(locals) {var pug_html = "", pug_mixins = {}, pug_interp;var pug_debug_filename, pug_debug_line;try {var pug_debug_sources = {};
;var locals_for_with = (locals || {});(function (tweets, twitter) {
pug_html = pug_html + "\u003Cdiv id=\"content\" style=\"font-family:GameFont;\"\u003E";
pug_html = pug_html + "\u003Cstyle\u003E";
;pug_debug_line = 5;
pug_html = pug_html + ".ss-wrapper {";
;pug_debug_line = 6;
pug_html = pug_html + "\n";
;pug_debug_line = 6;
pug_html = pug_html + "    overflow: hidden;";
;pug_debug_line = 7;
pug_html = pug_html + "\n";
;pug_debug_line = 7;
pug_html = pug_html + "    width: 100%;";
;pug_debug_line = 8;
pug_html = pug_html + "\n";
;pug_debug_line = 8;
pug_html = pug_html + "    height: 100%;";
;pug_debug_line = 9;
pug_html = pug_html + "\n";
;pug_debug_line = 9;
pug_html = pug_html + "    position: relative;";
;pug_debug_line = 10;
pug_html = pug_html + "\n";
;pug_debug_line = 10;
pug_html = pug_html + "    z-index: 1;";
;pug_debug_line = 11;
pug_html = pug_html + "\n";
;pug_debug_line = 11;
pug_html = pug_html + "    float: left;";
;pug_debug_line = 12;
pug_html = pug_html + "\n";
;pug_debug_line = 12;
pug_html = pug_html + "    display: flex;";
;pug_debug_line = 13;
pug_html = pug_html + "\n";
;pug_debug_line = 13;
pug_html = pug_html + "    flex-direction: column;";
;pug_debug_line = 14;
pug_html = pug_html + "\n";
;pug_debug_line = 14;
pug_html = pug_html + "}";
;pug_debug_line = 15;
pug_html = pug_html + "\n";
;pug_debug_line = 15;
pug_html = pug_html + "";
;pug_debug_line = 16;
pug_html = pug_html + "\n";
;pug_debug_line = 16;
pug_html = pug_html + ".ss-content {";
;pug_debug_line = 17;
pug_html = pug_html + "\n";
;pug_debug_line = 17;
pug_html = pug_html + "    height: 100%;";
;pug_debug_line = 18;
pug_html = pug_html + "\n";
;pug_debug_line = 18;
pug_html = pug_html + "    width: 100%;";
;pug_debug_line = 19;
pug_html = pug_html + "\n";
;pug_debug_line = 19;
pug_html = pug_html + "    padding: 0 32px 0 0;";
;pug_debug_line = 20;
pug_html = pug_html + "\n";
;pug_debug_line = 20;
pug_html = pug_html + "    position: relative;";
;pug_debug_line = 21;
pug_html = pug_html + "\n";
;pug_debug_line = 21;
pug_html = pug_html + "    right: -18px;";
;pug_debug_line = 22;
pug_html = pug_html + "\n";
;pug_debug_line = 22;
pug_html = pug_html + "    overflow: auto;";
;pug_debug_line = 23;
pug_html = pug_html + "\n";
;pug_debug_line = 23;
pug_html = pug_html + "    box-sizing: border-box;";
;pug_debug_line = 24;
pug_html = pug_html + "\n";
;pug_debug_line = 24;
pug_html = pug_html + "}";
;pug_debug_line = 25;
pug_html = pug_html + "\n";
;pug_debug_line = 25;
pug_html = pug_html + "";
;pug_debug_line = 26;
pug_html = pug_html + "\n";
;pug_debug_line = 26;
pug_html = pug_html + ".ss-scroll {";
;pug_debug_line = 27;
pug_html = pug_html + "\n";
;pug_debug_line = 27;
pug_html = pug_html + "    position: relative;";
;pug_debug_line = 28;
pug_html = pug_html + "\n";
;pug_debug_line = 28;
pug_html = pug_html + "    background: #4C8DAC;";
;pug_debug_line = 29;
pug_html = pug_html + "\n";
;pug_debug_line = 29;
pug_html = pug_html + "    width: 20px;";
;pug_debug_line = 30;
pug_html = pug_html + "\n";
;pug_debug_line = 30;
pug_html = pug_html + "    border-radius: 0;";
;pug_debug_line = 31;
pug_html = pug_html + "\n";
;pug_debug_line = 31;
pug_html = pug_html + "    top: 0;";
;pug_debug_line = 32;
pug_html = pug_html + "\n";
;pug_debug_line = 32;
pug_html = pug_html + "    z-index: 2;";
;pug_debug_line = 33;
pug_html = pug_html + "\n";
;pug_debug_line = 33;
pug_html = pug_html + "    cursor: pointer;";
;pug_debug_line = 34;
pug_html = pug_html + "\n";
;pug_debug_line = 34;
pug_html = pug_html + "    opacity: 0;";
;pug_debug_line = 35;
pug_html = pug_html + "\n";
;pug_debug_line = 35;
pug_html = pug_html + "    transition: opacity 0.25s linear;";
;pug_debug_line = 36;
pug_html = pug_html + "\n";
;pug_debug_line = 36;
pug_html = pug_html + "}";
;pug_debug_line = 37;
pug_html = pug_html + "\n";
;pug_debug_line = 37;
pug_html = pug_html + "";
;pug_debug_line = 38;
pug_html = pug_html + "\n";
;pug_debug_line = 38;
pug_html = pug_html + ".ss-hidden {";
;pug_debug_line = 39;
pug_html = pug_html + "\n";
;pug_debug_line = 39;
pug_html = pug_html + "    display: none;";
;pug_debug_line = 40;
pug_html = pug_html + "\n";
;pug_debug_line = 40;
pug_html = pug_html + "}";
;pug_debug_line = 41;
pug_html = pug_html + "\n";
;pug_debug_line = 41;
pug_html = pug_html + "";
;pug_debug_line = 42;
pug_html = pug_html + "\n";
;pug_debug_line = 42;
pug_html = pug_html + ".ss-container:hover .ss-scroll {";
;pug_debug_line = 43;
pug_html = pug_html + "\n";
;pug_debug_line = 43;
pug_html = pug_html + "    opacity: 1;";
;pug_debug_line = 44;
pug_html = pug_html + "\n";
;pug_debug_line = 44;
pug_html = pug_html + "}";
;pug_debug_line = 45;
pug_html = pug_html + "\n";
;pug_debug_line = 45;
pug_html = pug_html + "";
;pug_debug_line = 46;
pug_html = pug_html + "\n";
;pug_debug_line = 46;
pug_html = pug_html + ".ss-grabbed {";
;pug_debug_line = 47;
pug_html = pug_html + "\n";
;pug_debug_line = 47;
pug_html = pug_html + "    -o-user-select: none;";
;pug_debug_line = 48;
pug_html = pug_html + "\n";
;pug_debug_line = 48;
pug_html = pug_html + "    -ms-user-select: none;";
;pug_debug_line = 49;
pug_html = pug_html + "\n";
;pug_debug_line = 49;
pug_html = pug_html + "    -moz-user-select: none;";
;pug_debug_line = 50;
pug_html = pug_html + "\n";
;pug_debug_line = 50;
pug_html = pug_html + "    -webkit-user-select: none;";
;pug_debug_line = 51;
pug_html = pug_html + "\n";
;pug_debug_line = 51;
pug_html = pug_html + "    user-select: none;";
;pug_debug_line = 52;
pug_html = pug_html + "\n";
;pug_debug_line = 52;
pug_html = pug_html + "}";
;pug_debug_line = 53;
pug_html = pug_html + "\n";
;pug_debug_line = 53;
pug_html = pug_html + "";
;pug_debug_line = 54;
pug_html = pug_html + "\n";
;pug_debug_line = 54;
pug_html = pug_html + "\u003C\u002Fstyle\u003E";
// iterate twitter.sprites
;(function(){
  var this$1 = this;

  var $$obj = twitter.sprites;
  if ('number' == typeof $$obj.length) {
      for (var pug_index0 = 0, $$l = $$obj.length; pug_index0 < $$l; pug_index0++) {
        var sprite = $$obj[pug_index0];
if (sprite.type === "div") {
pug_html = pug_html + "\u003Cdiv" + (" id=\"container\""+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': sprite.x + 'px',
                'top': sprite.y + 'px',
                'width': sprite.width + 'px',
                'height': sprite.height + 'px'
            }), true, true)) + "\u003E";
// iterate tweets.tweets
;(function(){
  var this$1 = this;

  var $$obj = tweets.tweets;
  if ('number' == typeof $$obj.length) {
      for (var pug_index1 = 0, $$l = $$obj.length; pug_index1 < $$l; pug_index1++) {
        var tweet = $$obj[pug_index1];
pug_html = pug_html + "\u003Cdiv" + (" class=\"tweet\""+pug.attr("style", pug.style({
    'background-image': ("url(\"" + (tweet.background) + "\")"),
    'background-repeat': "no-repeat",
    'background-position': "right",
    'height': '130px',
    'width': '610px',
    'position': 'relative'
}), true, true)) + "\u003E";
pug_html = pug_html + "\u003Cdiv class=\"container_name\" style=\"position:absolute;left:0px;top:0px;border-bottom:2px solid #888888;\"\u003E";
pug_html = pug_html + "\u003Cspan class=\"dash\" style=\"display:inline-block;border-bottom:2px solid #888888;width:38px;text-align:left;vertical-align:middle;\"\u003E\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"display_name\""+pug.attr("style", pug.style({
            'margin-right': '5px',
            'font-size': tweets.userNameSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.display_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"id_name\""+pug.attr("style", pug.style({
            'font-size': tweets.idSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.id_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv class=\"time\" style=\"position:absolute;left:401px;top:15px;\"\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.time) ? "" : pug_interp)) + "\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv" + (" class=\"content\""+pug.attr("style", pug.style({
        'position': 'absolute',
        'font-size': tweets.contentSize,
        'left': '20px',
        'top': '30px',
        'width': '300px'
    }), true, true)) + "\u003E";
pug_html = pug_html + (null == (pug_interp = tweet.content) ? "" : pug_interp) + "\u003C\u002Fdiv\u003E";
// iterate tweets.sprites
;(function(){
  var $$obj = tweets.sprites;
  if ('number' == typeof $$obj.length) {
      for (var pug_index2 = 0, $$l = $$obj.length; pug_index2 < $$l; pug_index2++) {
        var icon = $$obj[pug_index2];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
      }
  } else {
    var $$l = 0;
    for (var pug_index2 in $$obj) {
      $$l++;
      var icon = $$obj[pug_index2];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
      }
  } else {
    var $$l = 0;
    for (var pug_index1 in $$obj) {
      $$l++;
      var tweet = $$obj[pug_index1];
pug_html = pug_html + "\u003Cdiv" + (" class=\"tweet\""+pug.attr("style", pug.style({
    'background-image': ("url(\"" + (tweet.background) + "\")"),
    'background-repeat': "no-repeat",
    'background-position': "right",
    'height': '130px',
    'width': '610px',
    'position': 'relative'
}), true, true)) + "\u003E";
pug_html = pug_html + "\u003Cdiv class=\"container_name\" style=\"position:absolute;left:0px;top:0px;border-bottom:2px solid #888888;\"\u003E";
pug_html = pug_html + "\u003Cspan class=\"dash\" style=\"display:inline-block;border-bottom:2px solid #888888;width:38px;text-align:left;vertical-align:middle;\"\u003E\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"display_name\""+pug.attr("style", pug.style({
            'margin-right': '5px',
            'font-size': tweets.userNameSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.display_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"id_name\""+pug.attr("style", pug.style({
            'font-size': tweets.idSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.id_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv class=\"time\" style=\"position:absolute;left:401px;top:15px;\"\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.time) ? "" : pug_interp)) + "\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv" + (" class=\"content\""+pug.attr("style", pug.style({
        'position': 'absolute',
        'font-size': tweets.contentSize,
        'left': '20px',
        'top': '30px',
        'width': '300px'
    }), true, true)) + "\u003E";
pug_html = pug_html + (null == (pug_interp = tweet.content) ? "" : pug_interp) + "\u003C\u002Fdiv\u003E";
// iterate tweets.sprites
;(function(){
  var $$obj = tweets.sprites;
  if ('number' == typeof $$obj.length) {
      for (var pug_index3 = 0, $$l = $$obj.length; pug_index3 < $$l; pug_index3++) {
        var icon = $$obj[pug_index3];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
      }
  } else {
    var $$l = 0;
    for (var pug_index3 in $$obj) {
      $$l++;
      var icon = $$obj[pug_index3];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
}
else {
pug_html = pug_html + "\u003Cimg" + (pug.attr("id", sprite.id, true, true)+pug.attr("src", sprite.src, true, true)+pug.attr("style", pug.style({
                    'position': 'absolute',
                    'left': sprite.x + 'px',
                    'top': sprite.y + 'px'
                }), true, true)) + "\u003E";
}
      }
  } else {
    var $$l = 0;
    for (var pug_index0 in $$obj) {
      $$l++;
      var sprite = $$obj[pug_index0];
if (sprite.type === "div") {
pug_html = pug_html + "\u003Cdiv" + (" id=\"container\""+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': sprite.x + 'px',
                'top': sprite.y + 'px',
                'width': sprite.width + 'px',
                'height': sprite.height + 'px'
            }), true, true)) + "\u003E";
// iterate tweets.tweets
;(function(){
  var this$1 = this;

  var $$obj = tweets.tweets;
  if ('number' == typeof $$obj.length) {
      for (var pug_index4 = 0, $$l = $$obj.length; pug_index4 < $$l; pug_index4++) {
        var tweet = $$obj[pug_index4];
pug_html = pug_html + "\u003Cdiv" + (" class=\"tweet\""+pug.attr("style", pug.style({
    'background-image': ("url(\"" + (tweet.background) + "\")"),
    'background-repeat': "no-repeat",
    'background-position': "right",
    'height': '130px',
    'width': '610px',
    'position': 'relative'
}), true, true)) + "\u003E";
pug_html = pug_html + "\u003Cdiv class=\"container_name\" style=\"position:absolute;left:0px;top:0px;border-bottom:2px solid #888888;\"\u003E";
pug_html = pug_html + "\u003Cspan class=\"dash\" style=\"display:inline-block;border-bottom:2px solid #888888;width:38px;text-align:left;vertical-align:middle;\"\u003E\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"display_name\""+pug.attr("style", pug.style({
            'margin-right': '5px',
            'font-size': tweets.userNameSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.display_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"id_name\""+pug.attr("style", pug.style({
            'font-size': tweets.idSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.id_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv class=\"time\" style=\"position:absolute;left:401px;top:15px;\"\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.time) ? "" : pug_interp)) + "\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv" + (" class=\"content\""+pug.attr("style", pug.style({
        'position': 'absolute',
        'font-size': tweets.contentSize,
        'left': '20px',
        'top': '30px',
        'width': '300px'
    }), true, true)) + "\u003E";
pug_html = pug_html + (null == (pug_interp = tweet.content) ? "" : pug_interp) + "\u003C\u002Fdiv\u003E";
// iterate tweets.sprites
;(function(){
  var $$obj = tweets.sprites;
  if ('number' == typeof $$obj.length) {
      for (var pug_index5 = 0, $$l = $$obj.length; pug_index5 < $$l; pug_index5++) {
        var icon = $$obj[pug_index5];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
      }
  } else {
    var $$l = 0;
    for (var pug_index5 in $$obj) {
      $$l++;
      var icon = $$obj[pug_index5];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
      }
  } else {
    var $$l = 0;
    for (var pug_index4 in $$obj) {
      $$l++;
      var tweet = $$obj[pug_index4];
pug_html = pug_html + "\u003Cdiv" + (" class=\"tweet\""+pug.attr("style", pug.style({
    'background-image': ("url(\"" + (tweet.background) + "\")"),
    'background-repeat': "no-repeat",
    'background-position': "right",
    'height': '130px',
    'width': '610px',
    'position': 'relative'
}), true, true)) + "\u003E";
pug_html = pug_html + "\u003Cdiv class=\"container_name\" style=\"position:absolute;left:0px;top:0px;border-bottom:2px solid #888888;\"\u003E";
pug_html = pug_html + "\u003Cspan class=\"dash\" style=\"display:inline-block;border-bottom:2px solid #888888;width:38px;text-align:left;vertical-align:middle;\"\u003E\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"display_name\""+pug.attr("style", pug.style({
            'margin-right': '5px',
            'font-size': tweets.userNameSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.display_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E";
pug_html = pug_html + "\u003Cspan" + (" class=\"id_name\""+pug.attr("style", pug.style({
            'font-size': tweets.idSize
        }), true, true)) + "\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.id_name) ? "" : pug_interp)) + "\u003C\u002Fspan\u003E\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv class=\"time\" style=\"position:absolute;left:401px;top:15px;\"\u003E";
pug_html = pug_html + (pug.escape(null == (pug_interp = tweet.time) ? "" : pug_interp)) + "\u003C\u002Fdiv\u003E";
pug_html = pug_html + "\u003Cdiv" + (" class=\"content\""+pug.attr("style", pug.style({
        'position': 'absolute',
        'font-size': tweets.contentSize,
        'left': '20px',
        'top': '30px',
        'width': '300px'
    }), true, true)) + "\u003E";
pug_html = pug_html + (null == (pug_interp = tweet.content) ? "" : pug_interp) + "\u003C\u002Fdiv\u003E";
// iterate tweets.sprites
;(function(){
  var $$obj = tweets.sprites;
  if ('number' == typeof $$obj.length) {
      for (var pug_index6 = 0, $$l = $$obj.length; pug_index6 < $$l; pug_index6++) {
        var icon = $$obj[pug_index6];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
      }
  } else {
    var $$l = 0;
    for (var pug_index6 in $$obj) {
      $$l++;
      var icon = $$obj[pug_index6];
if (icon.type === 'img') {
pug_html = pug_html + "\u003Cimg" + (pug.attr("class", pug.classes([icon.id], [true]), false, true)+pug.attr("data-tweet-id", tweet.id, true, true)+pug.attr("data-rt-switch", tweet.rtSwitch || 0, true, true)+pug.attr("data-like-switch", tweet.likeSwitch || 0, true, true)+pug.attr("data-show-switch", tweet.showSwitch || 0, true, true)+pug.attr("src", icon.src, true, true)+pug.attr("style", pug.style({
                'position': 'absolute',
                'left': icon.x + 'px',
                'top': icon.y + 'px'
            }), true, true)) + "\u003E";
}
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
    }
  }
}).call(this$1);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";
}
else {
pug_html = pug_html + "\u003Cimg" + (pug.attr("id", sprite.id, true, true)+pug.attr("src", sprite.src, true, true)+pug.attr("style", pug.style({
                    'position': 'absolute',
                    'left': sprite.x + 'px',
                    'top': sprite.y + 'px'
                }), true, true)) + "\u003E";
}
    }
  }
}).call(this);

pug_html = pug_html + "\u003C\u002Fdiv\u003E";}.call(this,"tweets" in locals_for_with?locals_for_with.tweets:typeof tweets!=="undefined"?tweets:undefined,"twitter" in locals_for_with?locals_for_with.twitter:typeof twitter!=="undefined"?twitter:undefined));} catch (err) {pug.rethrow(err, pug_debug_filename, pug_debug_line, pug_debug_sources[pug_debug_filename]);};return pug_html;};

/*
	ユーザー名	id
整列ID	内容	RT時ONになるスイッチ	Like時ONになるスイッチ	このスイッチがONの時表示	このスイッチがOFFのとき表示
01_0603	おごってもらった、満腹。	1	2	5
01_1233	おなか減った！！	1	2		5

 */


/*:ja
 * @plugindesc liply_TwitterNew
 * @author liply
 *
 * @param FontSize:Id
 * @default 20
 *
 * @param FontSize:Content
 * @default 20
 *
 * @param FontSize:UserName
 * @default 20
 *
 * @param Opacity:RT,Like
 * @default 100
 *
 *
 */


var parameters = PluginManager.parameters('liply_TwitterNew');
var contentSize = parameters['FontSize:Content'] + 'px';
var idSize = parameters['FontSize:Id'] + 'px';
var userNameSize = parameters['FontSize:UserName'] + 'px';
var opacity = +(parameters['Opacity:RT,Like'] || 100);

//
// table fetch
//
function id2time(id){
    var result = id.match(/(..)_(..)(..)/);
    return ((result[2]) + ":" + (result[3]));
}

function id2timeNumber(id){
    var result = id.match(/(..)_(..)(..)/);
    return +result[2] * 60 + result[3];
}

function id2scene(id){
    var result = id.match(/(..)_(..)(..)/);
    return +result[1];
}

function numberOrNull(str){
    var number = +str;
    if(isNaN(number)) return null;
    return number;
}

var skin = ImageManager.loadSystem('Window');

function getColorFromSkin(n){
    var px = 96 + (n % 8) * 12 + 6;
    var py = 144 + Math.floor(n / 8) * 12 + 6;
    return skin.getPixel(px, py);
}

function getColor(colorNo){
    return getColorFromSkin(colorNo);
}

function processColor(text){
    var color = -1;
    var result = '';

    while(text.length !== 0){
        switch(text[0]){
            case '\\':
                var re = /^\\c\[(\d)]/g;
                var match = re.exec(text);
                if(match){
                    if(color !== -1){
                        result += '</span>';
                    }
                    color = +match[1];
                    result += "<span style=\"color:" + (getColor(color)) + ";\">";
                    text = text.slice(re.lastIndex);
                }else{
                    result += text[0];
                    text = text.slice(1);
                }
                break;

            default:
                result += text[0];
                text = text.slice(1);
        }
    }

    if(color !== -1){
        result += '</span>';
    }

    return result;
}

function convertTableToTweets(table){
    var backgroundTable = {
        '@extream_bochi': 'bocchi',
        '@akibaooohhh': 'akiha',
        '@mimimimimimimi': 'mikun',
        '@kaito_222': 'ogataka',
        '@operanian': 'opera',
        '@yuruyuruman': 'takatsu',
        '@asagiiro': 'tani',
        '@yanbou_manbou': 'coba',
        '@sogo_ultima': 'sogo',
    };

    var tweetTemplate = {
        display_name: table[0][1],
        id_name: table[0][2],
        background: ("twitter/images/icon/" + (backgroundTable[table[0][2]]) + ".png")
    };

    var tweets = table.slice(2);
    return tweets
        .filter(function (t){ return t[0]; })
        .map(function (t){ return (Object.assign({
            time: id2time(t[0]),
            sceneNumber: id2scene(t[0]),
            id: t[0],
            order: +id2timeNumber(t[0]),
            content: processColor(t[1]),
            rtSwitch: numberOrNull(t[2]),
            likeSwitch: numberOrNull(t[3]),
            showSwitch: numberOrNull(t[4])
        }, tweetTemplate)); });
}

function toTweets(tables){
    return Object.keys(tables)
        .map(function (key){ return tables[key]; })
        .reduce(function (prev,current){ return (
            prev.concat(convertTableToTweets(current))); }, []);
}

function replaceUrl(json){
    return json.data.map(function (elem){
        if(elem.src)
            elem.src = elem.src.replace('res://', './twitter/');
        return elem;
    });
}

function setUserProfile(id){
    var elem = document.querySelector('#user_profile');
    elem.src = "twitter/images/user_profile/" + id + "/user_profile.png";
}

function showTweetScreen(sceneNumber, userId, followers){
    var tweets = toTweets($dataTweet)
        .filter(function (t){ return (t.sceneNumber === sceneNumber); })
        .filter(function (t){ return ((t.showSwitch)?$gameSwitches.value(t.showSwitch): true); })
        .sort(function (l,r){ return (r.order-l.order); });

    var params = {
        tweets: {
            sprites: $dataSpriteTweet,
            userNameSize: userNameSize,
            idSize: idSize,
            contentSize: contentSize,
            tweets: tweets
        },
        twitter: {
            sprites: $dataSpriteTwitter
        }
    };

    var screen = document.querySelector('#twitter');
    screen.innerHTML = templateTwitter(params);
    setUserProfile(userId);
    bindHandlers(userId, followers);

    SceneManager.suspendFlag = true;
    screen.style.visibility = 'visible';
}


function hideTweetScreen(){
    SceneManager.suspendFlag = false;
    var screen = document.querySelector('#twitter');

    screen.innerHTML = '';
    screen.style.visibility = 'hidden';
}

function initTweetScreen(){
    var screen = document.createElement('div');
    screen.id = 'twitter';
    screen.style.zIndex = '1000';
    screen.style.width = '816px';
    screen.style.height = '624px';
    screen.style.overflow = 'hidden';
    screen.style.backgroundColor = '#4C8DAC';
    screen.style.visibility = 'hidden';

    document.body.appendChild(screen);

    var script = document.createElement('script');
    script.src = 'twitter/lib/simple-scrollbar.js';
    document.body.appendChild(script);
}



//////////////////////////////////////////
// Sounds
//////////////////////////////////////////
function playSound(name){
    var ext = AudioManager.audioFileExt();
    var url = "twitter/sounds/" + (encodeURIComponent(name)) + ext;
    var webAudio = new WebAudio(url);
    webAudio.play();
}

function playRtSound(){
    playSound('Wind1');
}

function playLikeSound(){
    playSound('Flash2');
}

function playCloseSound(){
    playSound('button68');
}



//////////////////////////////////////////
// Handlers
//////////////////////////////////////////


var iconData ={
    icon_rt:{
        on : './twitter/images/icon_rt_select.png',
        off : './twitter/images/icon_rt.png',
    },
    icon_like:{
        on : './twitter/images/icon_like_select.png',
        off : './twitter/images/icon_like.png',
    }
};

function onIcon(el){
    Object.keys(iconData).forEach(function (key){
        if(el.classList.contains(key)){
            el.src = iconData[key].on;
        }
    });
}


function offIcon(el){
    Object.keys(iconData).forEach(function (key){
        if(el.classList.contains(key)){
            el.src = iconData[key].off;
        }
    });
}

function setIcon(el, flag){
    if(flag)onIcon(el);
    else offIcon(el);
}

function disableIcon(el){
    el.style.opacity = opacity / 255;
}

function toCoverImage(src){
    var splat = src.split('/');
    splat[splat.length-1] = 'cover.png';
    return splat.join('/');
}

function showProfile(id){
    var profile = document.createElement('div');
    profile.style.backgroundColor = 'rgba(0,0,0, 0.5)';
    profile.style.position = 'absolute';
    profile.style.width = '816px';
    profile.style.height = '624px';
    profile.style.zIndex = '1001';

    var img = document.createElement('img');
    img.src = "./twitter/images/popup/" + id + ".png";
    img.style.position = 'absolute';
    img.style.zIndex = '1002';

    var close = function () {
        profile.parentNode.removeChild(profile);
        img.parentNode.removeChild(img);
    };

    profile.onclick = close;
    img.onclick = close;

    document.body.appendChild(profile);
    document.body.appendChild(img);
    centering(profile);
    centering(img);
    img.style.width = null;
    img.style.height = null;
}

function wrapUserElement(id, elem){
    var src = "twitter/images/user_profile/" + id + "/user_profile.png";
    var cover = toCoverImage(src);
    elem.src = src;

    var coverElem = elem.cloneNode(false);
    coverElem.src = cover;
    coverElem.style.visibility = 'hidden';
    coverElem.style.left = 0;
    coverElem.style.top = 0;

    var wrapper = document.createElement('div');
    wrapper.style.position = 'absolute';
    wrapper.style.left = elem.style.left;
    wrapper.style.top = elem.style.top;
    elem.style.top = 0;
    elem.style.left = 0;

    var parent = elem.parentNode;
    wrapper.appendChild(elem);
    wrapper.appendChild(coverElem);
    parent.appendChild(wrapper);

    wrapper.onmouseenter = function (){
        coverElem.style.visibility = 'visible';
    };
    wrapper.onmouseleave = function (){
        coverElem.style.visibility = 'hidden';
    };

    return wrapper;
}


function wrapFollowerElement(id, elem){
    var src = "twitter/images/follower_profile/" + id + "/follower_profile.png";
    var cover = toCoverImage(src);
    elem.src = src;

    var coverElem = elem.cloneNode(false);
    coverElem.src = cover;
    coverElem.style.visibility = 'hidden';
    coverElem.style.left = 0;
    coverElem.style.top = 0;

    var wrapper = document.createElement('div');
    wrapper.style.position = 'absolute';
    wrapper.style.left = elem.style.left;
    wrapper.style.top = elem.style.top;
    elem.style.top = 0;
    elem.style.left = 0;

    var parent = elem.parentNode;
    wrapper.appendChild(elem);
    wrapper.appendChild(coverElem);
    parent.appendChild(wrapper);

    wrapper.onmouseenter = function (){
        coverElem.style.visibility = 'visible';
    };
    wrapper.onmouseleave = function (){
        coverElem.style.visibility = 'hidden';
    };

    return wrapper;
}

function bindHandlers(userId, followers){
    function q(selector){
        return document.querySelector(selector);
    }
    function qa(selector){
        return Array.prototype.slice.call(document.querySelectorAll(selector),0);
    }

    SimpleScrollbar.initEl(q('#container'));

    qa('.icon_rt').forEach(function (el){
        var rtSwitch = +el.dataset.rtSwitch;
        if(rtSwitch){
            setIcon(el, $gameSwitches.value(rtSwitch));

            el.onclick = function(){
                $gameSwitches.setValue(rtSwitch, !$gameSwitches.value(rtSwitch));
                setIcon(el, $gameSwitches.value(rtSwitch));
                playRtSound();
            }
        }else{
            disableIcon(el);
        }
    });

    qa('.icon_like').forEach(function (el){
        var likeSwitch = +el.dataset.likeSwitch;
        if(likeSwitch){
            setIcon(el, $gameSwitches.value(likeSwitch));

            el.onclick = function(){
                $gameSwitches.setValue(likeSwitch, !$gameSwitches.value(likeSwitch));
                setIcon(el, $gameSwitches.value(likeSwitch));
                playLikeSound();
            }
        }else{
            disableIcon(el);
        }
    });

    var close = q('#close');
    close.onclick = function(){
        hideTweetScreen();
        playCloseSound();
    };

    var userProfile = q('#user_profile');
    var wrappedUserProfile = wrapUserElement(userId, userProfile);
    wrappedUserProfile.onclick = function(){
        showProfile(userId);
    };

    followers.forEach(function (id,idx){
            var elem = q('#follower'+(idx+1));
            var wrapper = wrapFollowerElement(id, elem);

            //setup popup
            wrapper.onclick = function (){
                showProfile(id);
            }
        });
}

//////////////////////////////////////////
//hooks
//////////////////////////////////////////

/*
(setFollowerProfile)
mikun
bochi
akiha
takatsu
ogataka
koba
opera
tani

(setUserProfile)
bochi
mikun
togawa

(defaultFollower)
mikun 　
bochi　
akiha
takatsu
ogataka
koba
opera
tani
 */

var followerTable = [
    'mikun',
    'bocchi',
    'akiha',
    'takatsu',
    'ogataka',
    'coba',
    'opera',
    'tani'
];

var idTable = {
    mikun: 'mikun',
    bochi: 'bocchi',
    akiha: 'akiha',
    takatsu: 'takatsu',
    ogataka: 'ogataka',
    koba: 'coba',
    opera: 'opera',
    tani: 'tani',
    togawa: 'togawa'
};

function createFollowerTable(masterTable, user, follower){
    var table = masterTable.slice(0);
    table.splice(table.indexOf(user), 1);
    table.splice(table.indexOf(follower), 1);
    table.unshift(follower);

    return table;
}

var Scene_Boot_start = Scene_Boot.prototype.start;
Scene_Boot.prototype.start = function(){
    Scene_Boot_start.apply(this, arguments);
};

var Game_Interpreter_pluginCommand = Game_Interpreter.prototype.pluginCommand;
Game_Interpreter.prototype.pluginCommand = function(cmd, args){
    switch(cmd.toLowerCase()){
        case 'tweet':
            var user = idTable[$gameVariables._userProfile] || 'bocchi';
            var follower = idTable[$gameVariables._followerProfile] || 'bocchi';
            showTweetScreen(+args[0],
                user,
                 createFollowerTable(followerTable, user, follower)
            );
            break;

        case 'setFollowerProfile'.toLowerCase():
            $gameVariables._followerProfile = args[0];
            break;

        case 'setUserProfile'.toLowerCase():
            $gameVariables._userProfile = args[0];
            break;
    }

    return Game_Interpreter_pluginCommand.apply(this, arguments);
};

function centering(id){
    var element = (typeof id === 'string')? document.querySelector(id): id;

    element.style.position = 'absolute';
    element.style.top = '50%';
    element.style.left = '50%';
    element.style.right = 0;
    element.style.bottom = 0;

    var s = Graphics._realScale;
    element.style.transform = "translate(-50%, -50%) scale(" + s + ", " + s + ")";
}

var Graphics_createAllElements = Graphics._createAllElements;
Graphics._createAllElements = function(){
    Graphics_createAllElements.call(this);
    initTweetScreen();
    centering('#twitter');
};

var Graphics_updateAllElements = Graphics._updateAllElements;
Graphics._updateAllElements = function(){
    Graphics_updateAllElements.call(this);
    centering('#twitter');
};

var DataManager_onLoad = DataManager.onLoad;
DataManager.onLoad = function(object){
    DataManager_onLoad.call(this, object);

    if(object === $dataSpriteTwitter){
        $dataSpriteTwitter = replaceUrl($dataSpriteTwitter);
    }
    if(object === $dataSpriteTweet){
        $dataSpriteTweet = replaceUrl($dataSpriteTweet);
    }
};

DataManager._databaseFiles = DataManager._databaseFiles.concat([
    {name: '$dataTweet', src: 'Tweet.json'},
    {name: '$dataSpriteTwitter', src: 'sprites_twitter.json'},
    {name: '$dataSpriteTweet', src: 'sprites_tweet.json'}
]);

var SceneManager_updateScene = SceneManager.updateScene;
SceneManager.updateScene = function(){
    if(!SceneManager.suspendFlag){
        SceneManager_updateScene.apply(this, arguments);
    }
};

var SceneManager_renderScene = SceneManager.renderScene;
SceneManager.renderScene = function(){
    if(!SceneManager.suspendFlag){
        SceneManager_renderScene.apply(this, arguments);
    }
};

var TouchInput_onTouchStart = TouchInput._onTouchStart;
TouchInput._onTouchStart = function(){
    if(!SceneManager.suspendFlag){
        TouchInput_onTouchStart.apply(this, arguments);
    }
};

var TouchInput_onTouchMove = TouchInput._onTouchMove;
TouchInput._onTouchMove = function(){
    if(!SceneManager.suspendFlag){
        TouchInput_onTouchMove.apply(this, arguments);
    }
};

var TouchInput_onTouchEnd = TouchInput._onTouchEnd;
TouchInput._onTouchEnd = function(){
    if(!SceneManager.suspendFlag){
        TouchInput_onTouchEnd.apply(this, arguments);
    }
};

}());